from django import template
from django.template.defaultfilters import stringfilter

register = template.Library()

@register.filter
@stringfilter
def template_exists(value):
    try:
        template.loader.get_template(value)
        return True
    except template.TemplateDoesNotExist:
        return False


# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-28 18:28
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0024_auto_20170328_1751'),
    ]

    operations = [
        migrations.AlterField(
            model_name='categoryitem',
            name='itemTemplate',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='omCmsMain.itemLayout', to_field='itemLayoutName'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-22 20:24
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0008_auto_20170322_2004'),
    ]

    operations = [
        migrations.CreateModel(
            name='itemLayout',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('itemLayoutName', models.CharField(max_length=50, unique=True)),
                ('itemLayoutDescriptio', models.CharField(blank=True, max_length=150, null=True)),
            ],
        ),
        migrations.RenameField(
            model_name='categoryitem',
            old_name='itemStyle',
            new_name='itemTemplate',
        ),
        migrations.AddField(
            model_name='categoryitem',
            name='onMouseOverDescription',
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='categoryitem',
            name='itemLayout',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, to='omCmsMain.itemLayout', to_field='itemLayoutName'),
            preserve_default=False,
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-20 21:20
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0003_auto_20170320_1540'),
    ]

    operations = [
        migrations.AlterField(
            model_name='sitemaininfo',
            name='siteAdress',
            field=models.CharField(blank=True, max_length=250, null=True),
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='siteAnalytics',
            field=models.CharField(blank=True, max_length=250, null=True),
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='siteEmail',
            field=models.CharField(blank=True, max_length=250, null=True),
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='siteHeadBgImg',
            field=models.ImageField(blank=True, null=True, upload_to='media/omCmsMain/siteImages'),
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='siteLogo',
            field=models.ImageField(blank=True, null=True, upload_to='media/omCmsMain/siteImages'),
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='siteLongDescription',
            field=models.CharField(blank=True, max_length=250, null=True),
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='siteName',
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='sitePhone1',
            field=models.CharField(blank=True, max_length=250, null=True),
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='sitePhone2',
            field=models.CharField(blank=True, max_length=250, null=True),
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='siteShortDescription',
            field=models.CharField(blank=True, max_length=150, null=True),
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='siteTagLine1',
            field=models.CharField(blank=True, max_length=150, null=True),
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='siteTagLine2',
            field=models.CharField(blank=True, max_length=150, null=True),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-26 19:06
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0020_auto_20170323_1337'),
    ]

    operations = [
        migrations.AddField(
            model_name='sitemaininfo',
            name='siteHeaderWidth',
            field=models.IntegerField(blank=True, default=0, null=True),
        ),
        migrations.AddField(
            model_name='sitemaininfo',
            name='siteHeadrHeigth',
            field=models.IntegerField(blank=True, default=0, null=True),
        ),
        migrations.AddField(
            model_name='sitemaininfo',
            name='siteLogoHeigth',
            field=models.IntegerField(blank=True, default=0, null=True),
        ),
        migrations.AddField(
            model_name='sitemaininfo',
            name='siteLogoWidth',
            field=models.IntegerField(blank=True, default=0, null=True),
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='siteHeadBgImg',
            field=models.ImageField(blank=True, null=True, upload_to='siteImages/'),
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='siteLogo',
            field=models.ImageField(blank=True, null=True, upload_to='siteImages/'),
        ),
        migrations.AlterField(
            model_name='sitesocialmediareference',
            name='smLogo',
            field=models.ImageField(null=True, upload_to='socialMediaImages/'),
        ),
    ]



# Local Settings for omCmsMain
# To be included in project settings

STATIC_URL = '/static/'
MEDIA_ROOT = '/home/rtavares/DATA/develop/python/django/omCms/omCms/omCmsMain/media/omCmsMain'
MEDIA_URL = '/media/'

print "MEDIA_URL: ", MEDIA_URL

EMAIL_USE_TLS = True
EMAIL_HOST = 'smtp.gmail.com'
EMAIL_PORT = 587
EMAIL_HOST_USER = 'register.me.alubrat2017@gmail.com'
EMAIL_HOST_PASSWORD = '#Login2017'



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-10 12:13
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0029_auto_20170406_2203'),
    ]

    operations = [
        migrations.CreateModel(
            name='theme',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('themeName', models.CharField(max_length=50, unique=True)),
                ('themeDescription', models.TextField(blank=True, null=True)),
            ],
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='siteTheme',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='omCmsMain.theme', to_field='themeName'),
        ),
    ]



from django.contrib import admin

from .models import categoryItem
from .models import siteMainInfo
from .models import siteSocialMediaReference
from .models import contentArticle
from .models import itemLayout
from .models import theme

# Register your models here.

admin.site.register(categoryItem)
admin.site.register(siteMainInfo)
admin.site.register(siteSocialMediaReference)
admin.site.register(contentArticle)
admin.site.register(itemLayout)
admin.site.register(theme)



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-22 22:41
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0015_auto_20170322_2232'),
    ]

    operations = [
        migrations.AddField(
            model_name='categoryitem',
            name='itemsByLine',
            field=models.IntegerField(blank=True, default=0, null=True),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-28 17:51
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0023_auto_20170328_1731'),
    ]

    operations = [
        migrations.AddField(
            model_name='itemlayout',
            name='itemLayoutSortDescription',
            field=models.CharField(blank=True, max_length=150, null=True),
        ),
        migrations.AlterField(
            model_name='itemlayout',
            name='itemLayoutDescription',
            field=models.TextField(blank=True, null=True),
        ),
    ]



from django.shortcuts import render

from .models import categoryItem
from .models import siteMainInfo
from .models import siteSocialMediaReference
from .models import contentArticle


# Create your views here.

def baseIndex(request):
    """
        Home page index
    """

    context = {}

    siteInfoData = siteMainInfo.objects.get(active=1)

    categorysList = categoryItem.objects.filter(itemActive=1).filter(itemOrder__gt=0).order_by('itemOrder')

    articlesList = contentArticle.objects.filter(active=1).order_by('order')
    articlesListHomePage = contentArticle.objects.filter(active=1).filter(articleCategory__itemCategory__contains='homepage').order_by('order')
    
    context['siteInfoData'] = siteInfoData
    #context['siteTheme']  = str(context['siteInfoData'].siteTheme.themeName)

    context['categorysList'] = categorysList
    context['articlesList'] = articlesList
    context['articlesListHomePage'] = articlesListHomePage

    siteTheme =  siteInfoData.siteTheme.themeName if siteInfoData.siteTheme.themeName else "omCms"

    template = "omCmsMain/themes/"+siteTheme+"/index.html"

    return render(request, template, context)

def categoryArticleDetail(request, category="", article_id=0):
    """
        Detail for Article  in category
    """
    
    context = {}

    siteInfoData = siteMainInfo.objects.get(active=1)
    categorysList = categoryItem.objects.filter(itemActive=1).filter(itemOrder__gt=0).order_by('itemOrder')

    article = contentArticle.objects.get(pk=article_id)

    context['siteInfoData'] = siteInfoData
    context['categorysList'] = categorysList
    context['category'] = category
    context['article_id'] = article_id
    context['article'] = article

    siteTheme =  siteInfoData.siteTheme.themeName if siteInfoData.siteTheme.themeName else "omCms"

    template = "omCmsMain/themes/"+siteTheme+"/detail.html"

    return render(request, template, context)



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-22 19:56
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0006_sitemaininfo_active'),
    ]

    operations = [
        migrations.AddField(
            model_name='sitemaininfo',
            name='recordReference',
            field=models.CharField(default='First', max_length=50, unique=True),
            preserve_default=False,
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-20 15:32
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0001_initial'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='categoryItems',
            new_name='categoryItem',
        ),
        migrations.RenameModel(
            old_name='siteSocialMediaReferences',
            new_name='siteSocialMediaReference',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-22 20:32
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0011_auto_20170322_2029'),
    ]

    operations = [
        migrations.RenameField(
            model_name='itemlayout',
            old_name='itemLayoutDescriptio',
            new_name='itemLayoutDescription',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-04-05 20:35
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0026_auto_20170328_2128'),
    ]

    operations = [
        migrations.AlterField(
            model_name='contentarticle',
            name='body1Image',
            field=models.ImageField(blank=True, null=True, upload_to='articleImages/'),
        ),
        migrations.AlterField(
            model_name='contentarticle',
            name='body2Image',
            field=models.ImageField(blank=True, null=True, upload_to='articleImages/'),
        ),
        migrations.AlterField(
            model_name='contentarticle',
            name='body3Image',
            field=models.ImageField(blank=True, null=True, upload_to='articleImages/'),
        ),
        migrations.AlterField(
            model_name='contentarticle',
            name='teaserImage',
            field=models.ImageField(blank=True, null=True, upload_to='articleImages/'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-11 09:13
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0031_sitemaininfo_displaydrawrmenu'),
    ]

    operations = [
        migrations.AddField(
            model_name='sitemaininfo',
            name='allwaysDisplayDrawrMenu',
            field=models.BooleanField(default=True),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-20 15:19
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='categoryItems',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('itemCategory', models.CharField(max_length=50)),
                ('itemActive', models.IntegerField(default=0)),
                ('loggedOnly', models.IntegerField(default=1)),
                ('itemOrder', models.IntegerField(default=0)),
                ('itemDescription', models.CharField(blank=True, max_length=50, null=True)),
                ('itemMouseOver', models.CharField(blank=True, max_length=150, null=True)),
                ('itemLinkTo', models.CharField(blank=True, max_length=150, null=True, verbose_name='linkTo - Default: itemCategory')),
            ],
        ),
        migrations.CreateModel(
            name='siteMaininfo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('siteName', models.CharField(max_length=50)),
                ('siteLogo', models.ImageField(null=True, upload_to='media/omCmsMain/siteImages')),
                ('siteHeadBgImg', models.ImageField(null=True, upload_to='media/omCmsMain/siteImages')),
                ('siteShortDescription', models.CharField(max_length=150)),
                ('siteTagLine1', models.CharField(max_length=150)),
                ('siteTagLine2', models.CharField(max_length=150)),
                ('siteLongDescription', models.CharField(max_length=250)),
                ('siteAnalytics', models.CharField(max_length=250)),
                ('siteAdress', models.CharField(max_length=250)),
                ('sitePhone1', models.CharField(max_length=250)),
                ('sitePhone2', models.CharField(max_length=250)),
                ('siteEmail', models.CharField(max_length=250)),
            ],
        ),
        migrations.CreateModel(
            name='siteSocialMediaReferences',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('smName', models.CharField(max_length=50)),
                ('smLogo', models.ImageField(null=True, upload_to='media/omCmsMain/siteImages')),
                ('smLink', models.CharField(max_length=100)),
            ],
        ),
    ]
